<?php
/**
 * Class to obfuscate email addresses, then defuscate them with jQuery
 *
 * Contains an edited version of 
 * Email Defuscator - jQuery plugin 1.0 alpha Copyright (c) 2007 Joakim Stai
 * Dual licensed under the MIT and GPL licenses:
 *   http://www.opensource.org/licenses/mit-license.php
 *   http://www.gnu.org/licenses/gpl.html
 * 
 * Contains jQuery rot13 function from 
 *   http://onehackoranother.com/projects/jquery/jquery-grab-bag/
 * 
 * @package Obfuscator
 * @author Micha Wotton <micha.wotton@gmail.com>
 * @copyright (C) 2010 Micha Wotton
 * @link http://webstuff.biz/
 * @version 0.1
 */
class Obfuscator extends CApplicationComponent
{
  
  /**
  * The email address to obfuscate
  * 
  * @var str 
  */
  public $email;
  
  /**
  * The string to use when replacing the '@' symbol 
  * 
  * @var string
  */
  public $at;
  
  /**
  * This is the primary obfuscating method.
  * The goal is to be able to call this thru Yii::app()->obfuscator->disguise('name@example.com')
  * 
  * @param mixed $email
  * 
  * @param bool $link (default is 'true') - specify whether the email address should be wrapped in a mailto: link
  */
  
  
  public function disguise($email=null,$link = true,$at=null){
    $result = '';
    if ($at != null){
      $this->at = $at;
    } else {
      $this->at = '('.chr(rand(97,122)).chr(rand(97,122)).chr(rand(97,122)).')';
    }
    
    $addressArray = explode('@',$email,2);
    $user = $addressArray[0];
    $host = $addressArray[1];
    
    $user = str_rot13($user);
    $host = str_rot13($host);
    $result = join($this->at,array($user,$host));
    
    $rot13function = '
    $.fn.rot13 = function() {
        this.each(function() {
            $(this).text($(this).text().replace(/[a-z0-9]/ig, function(chr) {
                var cc = chr.charCodeAt(0);
                if (cc >= 65 && cc <= 90) cc = 65 + ((cc - 52) % 26);
                else if (cc >= 97 && cc <= 122) cc = 97 + ((cc - 84) % 26);
                else if (cc >= 48 && cc <= 57) cc = 48 + ((cc - 43) % 10);
                return String.fromCharCode(cc);
            }));
        });
        return this;
    };
    ';
    
    $defuscatefunction="
      /*
      * Email Defuscator - jQuery plugin 1.0 alpha
      *
      * Copyright (c) 2007 Joakim Stai
      *
      * Dual licensed under the MIT and GPL licenses:
      *   http://www.opensource.org/licenses/mit-license.php
      *   http://www.gnu.org/licenses/gpl.html
      *
      *
      */

      /**
      * Converts obfuscated email addresses into normal, working email addresses.
      *
      * @name defuscate
      * @param Boolean link If true, all defuscated email addresses will be turned into links, defaults to true (optional)
      * @descr Converts obfuscated email addresses into normal email addresses
      */

      jQuery.fn.defuscate = function( settings ) {
        settings = jQuery.extend({
        link: true
        }, settings);
        var regex = /\b([\w-\.]+)\([^)]+\)((?:[\w-]+\.)+[a-zA-Z]{2,6})\b/gi;
        return this.each(function() {
          
        // Defuscate the element's contents
          $(this).html($(this).html().replace(regex,  '$1@$2'));
          $(this).rot13();
          if (settings.link) {
            var address = $(this).html();
            $(this).html('<a href=\"mailto:'+ address +'\">'+ address +'</a>');
          }
        });
      }
      ";
    
    $unobs = '
    $(".obfuscated_link").defuscate({link:true});
    $(".obfuscated").defuscate({link:false});
    ';
    
    $cs = Yii::app()->clientScript;
    $cs->registerScript('rot13',$rot13function,CClientScript::POS_READY);
    $cs->registerScript('defuscate',$defuscatefunction,CClientScript::POS_READY);
    $cs->registerScript('defuscateready',$unobs,CClientScript::POS_READY);
    
    $class = ($link) ? 'obfuscated_link' : 'obfuscated';
    return '<span class="'.$class.'">'.$result.'</span>';
  }
  
}
?>

